@@ -1,6 +1,38 @@
 ### This file contains an assortment of random airfoils to use
 from aerosandbox.geometry.airfoil import Airfoil
 from aerosandbox.library.aerodynamics.viscous import *
+from aerosandbox.geometry.airfoil.airfoil_families import get_NACA_coordinates, \
+    get_UIUC_coordinates
+
+
+def diamond_airfoil(
+        t_over_c: float,
+        n_points_per_panel=2,
+) -> Airfoil:
+    x_nondim = [1, 0.5, 0, 0.5, 1]
+    y_nondim = [0, 1, 0, -1, 0]
+
+    x = np.concatenate(
+        [
+            list(np.cosspace(a, b, n_points_per_panel))[:-1]
+            for a, b in zip(x_nondim[:-1], x_nondim[1:])
+        ] + [[x_nondim[-1]]]
+    )
+    y = np.concatenate(
+        [
+            list(np.cosspace(a, b, n_points_per_panel))[:-1]
+            for a, b in zip(y_nondim[:-1], y_nondim[1:])
+        ] + [[y_nondim[-1]]]
+    )
+    y = y * t_over_c
+
+    coordinates = np.array([x, y]).T
+
+    return Airfoil(
+        name="Diamond",
+        coordinates=coordinates,
+    )
+
 
 generic_cambered_airfoil = Airfoil(
     name="Generic Cambered Airfoil",
@@ -12,7 +44,8 @@ generic_cambered_airfoil = Airfoil(
     ),
     CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
         -0.1
-    )
+    ),
+    coordinates=get_UIUC_coordinates(name="clarky")
 )
 generic_airfoil = Airfoil(
     name="Generic Airfoil",
@@ -24,7 +57,8 @@ generic_airfoil = Airfoil(
     ),
     CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
         0
-    )  # TODO make this an actual curve!
+    ),  # TODO make this an actual curve!
+    coordinates=get_NACA_coordinates(name="naca0012")
 )
 
 e216 = Airfoil(
@@ -79,5 +113,13 @@ flat_plate = Airfoil(
     ),
     CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function
         0
-    )  # TODO make this an actual curve!
+    ),
+    coordinates=np.array([
+        [1, 0],
+        [1, 1e-6],
+        [0, 1e-6],
+        [0, -1e-6],
+        [1, -1e-6],
+        [1, 0],
+    ])
 )
