@@ -48,6 +48,44 @@ def cosspace(
     )
 
 
+def sinspace(
+        start: float = 0.,
+        stop: float = 1.,
+        num: int = 50,
+        reverse_spacing: bool = False,
+):
+    """
+    Makes a sine-spaced vector.
+
+    Sine spacing is exactly identical to half of a cosine-spaced distrubution, in terms of relative separations.
+
+    To learn more about sine spacing and cosine spacing, see this: https://youtu.be/VSvsVgGbN7I
+
+    Args:
+
+        start: Value to start at.
+
+        end: Value to end at.
+
+        num: Number of points in the vector.
+
+        reverse_spacing: Does negative-sine spacing. In other words, if this is True, the points will be bunched near
+        the `stop` rather than at the `start`.
+
+    Points are bunched up near the `start` of the interval by default. To reverse this, use the `reverse_spacing`
+    parameter.
+    """
+    if reverse_spacing:
+        return sinspace(stop, start, num)[::-1]
+    ones = 0 * start + 1
+    return start + (stop - start) * (1 - _onp.cos(linspace(
+        0 * ones,
+        _onp.pi / 2 * ones,
+        num
+    ))
+                                     )
+
+
 def logspace(
         start: float = 0.,
         stop: float = 1.,
